%% Pend_CSIDE_CalCurve.m
% by M.A. Pendergraft, with help from others ...
% I did not write any of the functions used
% version: 2020 december 18
% 
%% load these for input data ...
load 2019jan17.mat;
load C_2019mar18.mat;
%% ... or just ...
load 2019mar19.mat
% ... which should have all the data/outputs produced here
%
%% average the EEMs for the replicate scans
% AVGmaxCALpk = zeros(10,1);
% highest RU is 1.6, so have to use our highest concentration (15ppb) which
% yielded RU of 2.4.  5 ppb yield 0.8 RU
% Avg560579RUcal = zeros(10,1); 
% AVbgcND2cal = zeros(10,1); % not a 10x1
%
%% 3/19/19 - this ran.
% 10 RWT calibration curve solutions at different RWT concentrations
% all 10 were scanned once, then all 10 were scanned twice, then a third time
% below first makes a mean excitation-emission matrix from the 3 scans of each point/concentration (AVbgcND2cal_2)
% then from that matrix, the fluorescence values are pulled from the 3 RWT ex/em locations determined in Pend_CSIDE_ReadEEMS.m (G_exi_emi)
% and a mean value is taken (AVbgcND2calFluor_2)
for i=1:10 % 1:10 is first scan. 11:20 is second. 21:30 is third. avg produces just 10 values, hence i=1:10
% below grabs the background corrected data for the 3 scans of each cal curve concentration & takes the mean
    AVbgcND2cal_2 = (C(5).PEMfiles(i).bgcND2_2 + C(5).PEMfiles(i+10).bgcND2_2 + C(5).PEMfiles(i+20).bgcND2_2)/3;
    [C(5).PEMfiles(i).AVbgcND2cal_2] = AVbgcND2cal_2; % add value to C
    % and this one below takes the mean of the 3 RWT peaks
    AVbgcND2calFluor_2 = (C(5).PEMfiles(i).AVbgcND2cal_2(G_exi_emi(4),G_exi_emi(1))... % EEMs: rows-emission, cols-excitation
        + C(5).PEMfiles(i).AVbgcND2cal_2(G_exi_emi(5),G_exi_emi(2))...
        + C(5).PEMfiles(i).AVbgcND2cal_2(G_exi_emi(6),G_exi_emi(3)))/3;
    [C(5).PEMfiles(i).AVbgcND2calFluor_2] = AVbgcND2calFluor_2;
    clear AVbgcND2cal_2 AVbgcND2calFluor_2
end
%%
%
%
%% 3/19/19 generate bgcCal_2 
bgcCal_2 = zeros(10,2);
bgcCal_2(1:10) = [0;0.005;0.05;0.1;0.2;0.5;1;2;5;15];
%
%% in order to make a cal curve matrix w/ [RWT] & background corrected fluorescence
for m = 1:10
bgcCal_2(m+10) = C(5).PEMfiles(m).AVbgcND2calFluor_2;
end
%
%%
dlmwrite(sprintf('%s','cal_2019mar19.txt'),bgcCal_2,'\t'); % file included
%
%% plot cal curve
% x = PPBvsRU(:,1); % PPB on x axis because it is the independent variable
x = bgcCal_2(:,1); % PPB on x axis because it is the independent variable
y = bgcCal_2(:,2); % fluorescence b/c is dependent variable
calfig = figure;
plot(x,y,'ob','MarkerSize',10');
ylimsCalfig = [-0.2 2.75];  % 7/1 i flipped all the x and y lims
ylim(ylimsCalfig);
xlimsCalfig = [-1.5 17];
xlim(xlimsCalfig);
hold on
%
%% calculate regression w/ slope & y-int. 7/6 it worked on 7/3-4
%
T = [ones(length(x),1) x];
b = T\y; % b(1) is y-int, b(2) is slope
% prev: b(1) = 0.0069476 ; b(2) = 6.1667 ; y = 6.167x + 0.007  
% 7/2 - y-int (b(1)) = -0.0017 ; m (b(2)) = 0.1622
% 2018nov21 - b is same
% 3/19/19: y-int (b(1)) = -0.0039 ; m (b(2)) = 0.1599
%
%% plot the linear regression
yCalc2 = T*b;
plot(x,yCalc2,'--r');
xlabel('RWT (aq), PPB');    % 7/1 these are now flipped
ylabel('fluorescene, RU');  % they were: x: fluor, y: [RWT]
title('Background Corrected Calibration Curve');
legend('Data','Linear Regression','Location','Southeast');
%
set(findall(gcf,'-property','LineWidth'),'LineWidth',1.625);
set(findall(gcf,'-property','FontSize'),'FontSize',18);
%
%% calculate R^2
R2 = 1 - sum((y - yCalc2).^2)/sum((y - mean(y)).^2); 
% 7/6 R2 = 0.9999
% 3/19/19 R2 = 0.9999
%
%%
% text(8,2.2,'R^2 = 0.9999','Color','red','FontSize',14)
text(8,2.2,['R^2 = ' num2str(R2)],'Color','red','FontSize',14);
%
%% print -f2 -r1000 -djpeg fig3_print_2018nov25
% print -f1 -r400 -djpeg example_2019jan17
% print -f1 -r400 -dpng example_2019jan17
print -f1 -r400 -djpeg Cal_2019mar19
print -f1 -r400 -dpng Cal_2019mar19
%%
% savefig('example_2019jan17.fig');
savefig('Cal_2019mar19.fig');
%
%% save workspace
% save 2019mar19.mat