%% if you are going to run this, it will overwrite the outputs from:
% [IR, IRmed, IRdiff] = RamanIntegrationRange(RAMdata,[1:nRamScan]',350);
% from below (around line 57)...so you might want to comment out that line
%% INPUTS
% make sure you are in the directory that contains this file

%Multiple Raman Scans?(Yes = 1 / No = 0)
MultScan = 1;  % when have just one Raman scan

% Raman Scans File
RamanFile = 'Pend_CSIDE_Ramans.txt'; % this is the big file w/ "Fully Corrected Emission Spectra"
%Categories
AA = 1; %med gain; I have 1 or 2 in each data column indicating med or hi gain
BB = 2; %high gain

%OUTPUT FILENAME
% filename = 'HA_Calibration4_RamanAreas.txt';  
% I think this just creates the file; a table of Raman normalization values
filename = 'Pend_CSIDE_RamanAreas.txt';

%% Interpolate & Find Water Raman Peak Boundaries
if MultScan == 1;
    RamanScans_Raw = dlmread(RamanFile,'\t',5,0);  % start reading my file at 6th row, 1st column
    % first row in RamanFile is "1" for MedGain or "2" for HiGain
    % ^ 1st col: Em wavelenghts; columns 2-end: 2 columns for each day
    % samples were ran corresponding to med and hi gain
    RamSort = RamanScans_Raw(1,2:end); % just grabs 1's and 2's for Med/Hi gain
    RamSort = RamSort';
    RamanScans_Raw = RamanScans_Raw(2:end,:);  
    % removes 1's and 2's which are now the column vector RamSort
end

RamEM_raw = RamanScans_Raw(:,1);  % Emission Wavelengths
RamanScans_Raw = RamanScans_Raw(:,2:end);  
% Raman Scans - 11/20/16: the emission value/intensity at each emission wavelength
RamEM_interp = [250:1:600]';
RamanScan_interp = interp1(RamEM_raw,RamanScans_Raw,RamEM_interp);
plot(RamEM_raw,RamanScans_Raw,'black') % this puts a bunch of plots on top of each other
%                                      % I think it is plotting the EEM
%                                      with the Raman peak
hold
plot(RamEM_interp,RamanScan_interp,'red') % same? and then this does the same thing
%                                         % but for interpolated values
pause(3)
close

nRamScan = size(RamanScans_Raw,2); % yields 23 (23 columns)
RAMdata = [RamEM_interp' ; RamanScan_interp'];
% ^ wavelengths 250-600 in first row, 23 Em intensities in 23 rows below
[IR, IRmed, IRdiff] = RamanIntegrationRange(RAMdata,[1:nRamScan]',350); %% Insert #of Raman Scans into second field
% function [IR IRmed IRdiff] = RamanIntegrationRange(RAMmat,flist,landa,halfwidth,sequence,tolerance);
% Determine the integration range [min max] for the water Raman peak at 
% specified excitation wavelength (350nm) for a set of water Raman scans
%
%% I think this stuff below is old, goes together, and can be ignored:
% For 2+ Raman Datasets (e.g. 2 fluorimeters), see older version:
% (RamanScans_Interp_FindRange.m)
% Find Water Raman Peak Areas & Generate Raman Areas List
% Use in combination with RamanScans_Interp_FindRange.m %%%
%
%%
[ROW, COL] = size(RAMdata);
for i=2:ROW % ROW=24. i=23
    Rdata = [RAMdata(1,:) ; RAMdata(i,:)]; % Rdata = [Em wavelengths ; intensities]
    [RamArea,EmMin,EmMax] = RamanArea_mod(Rdata,IR(i-1,1),IR(i-1,2));
    % ^ Finds the area under the (Raman) curves in M between wavelengths EmMin and EmMax, with EmMin<EmMax
    % output from RamanArea_mod:
%     Actual integration range is 380 to 421 nm.
%     Actual integration range is 381 to 425 nm.
%     Actual integration range is 381 to 423 nm.
%     Actual integration range is 382 to 421 nm.
%     Actual integration range is 381 to 417 nm.
%     Actual integration range is 380 to 423 nm.
%     Actual integration range is 381 to 425 nm.
%     Actual integration range is 382 to 419 nm.
%     Actual integration range is 382 to 416 nm.
%     Actual integration range is 382 to 416 nm.
%     Actual integration range is 380 to 414 nm.
%     Actual integration range is 381 to 417 nm.
%     Actual integration range is 383 to 420 nm.
%     Actual integration range is 382 to 419 nm.
%     Actual integration range is 382 to 417 nm.
%     Actual integration range is 382 to 415 nm.
%     Actual integration range is 381 to 418 nm.
%     Actual integration range is 378 to 417 nm.
%     Actual integration range is 382 to 425 nm.
%     Actual integration range is 382 to 416 nm.
%     Actual integration range is 382 to 427 nm.
%     Actual integration range is 381 to 424 nm.
%     Actual integration range is 381 to 416 nm.
    if i==2 % I think this would be if there is just one sample maybe
        RamanArea_Unsorted = RamArea;
    else RamanArea_Unsorted = [RamanArea_Unsorted; RamArea];
    end
end

% added below 29 Dec 2015
Folders = RamanFile(2:2:end,:);

if MultScan == 1;
RamanTable = zeros(length(RamanArea_Unsorted),2);
for i=1:length(RamSort) % length RamSort=23
    if RamSort(i)==AA  % AA = 1; %med gain, % BB = 2; %high gain
                       % RamSort(i) lists those 1's and 2's from The
                       % RamanFile (CSIDE_Ramans2.txt), so this is taking
                       % into account gain
        RamanTable(i,1) = RamanArea_Unsorted(i);  % first column is med gain
        RamanTable(i,2) = RamanArea_Unsorted(i);  % second column is high gain
    elseif RamSort(i)==BB
        RamanTable(i-1,2) = RamanArea_Unsorted(i); % so no column 1 here?
                                                   % has just one column
                                                   % with all values from
                                                   % med and hi gain
    end
end
ff = find(RamSort==2);
RamanTable(ff,:) = [];
RamanAreas = RamanTable; 
% puts values for med gain in one column and values for hi gain in another
elseif MultScan == 0;
    RamanAreas = RamanArea_Unsorted;
end


%% Write Output File %%

if MultScan == 1;
    dlmwrite(filename,RamanAreas,'\t')  %NAME FILE FOR RAMAN UNIT NORMALIZATION VALUES
end

