function [bathymetry_mask,h] =  make_bathymetry_mask_CSIDE(id,dx,dy,varargin)
%
% USAGE:  [bathymetry_mask,h] =  make_bathymetry_mask_CSIDE(id,dx,dy,alim);
%
%=========================================
%% Input arguments: id,dx,dy
%=========================================
% id - date
% dx - x-axis spacing of gridded data
% dy - y-axis spacing of gridded data
% alim - axis limits [xmin xmax ymin ymax]
%========================================
%% Contents of output file
%========================================
% h - bathymetry matrix
% bathymetry_mask - mask of 1's and NaN's 


%% Load bathymetry data from NOAA Tsunami DEM
load('/data1/CSIDE/MASS/mat_data/CSIDEbathy_raw.mat')% vars are xs ys Zs 
                                                     % IB09 coords 
                                                     % Zs is bathy


%% set up axes
if isempty(varargin)
alim = get_alim_CSIDE(id);
else 
alim = varargin{1};
end

%% grid the bathymetry data
[Zq,xq,yq] = data_to_grid_CSIDE(xs,ys,Zs,alim,dx,dy,'cubic',0);% no masking necessary

% %% remove child bathy data above y=3200
% %  this part of the data has bad sections
% [X,Y] = meshgrid(xq,yq);
% A = find(Y>3200);
% child_bathy(A) = NaN;

% %====================================
% %% Make mask and gridded bathymetry
% %====================================
% h = NaN(size(parent_bathy)); % blank grid
% bathymetry_mask = ones(size(parent_bathy)); % initialize mask
% 
% % where the parent bathy has data, overwrite h
% A = find(~isnan(parent_bathy));
% h(A) = parent_bathy(A);
% 
% % where the child bathy has data, overwrite h
% % done second so that child overwrites parent
% A = find(~isnan(child_bathy));
% h(A) = child_bathy(A);

%% only 1 bathy file for CSIDE so define depth (h=Zq)
h = Zq;

% set the mask to NaN above sea level
A = find(h>0);
bathymetry_mask = ones(size(Zq));
bathymetry_mask(A) = NaN;

end
